set echo off

--DESCRIPTION
--This script, SHOW_PLAN.SQL displays a list of statement IDs from 
--the plan table, and prompts the user to enter one. The plan for 
--that statement is then displayed a hierarchical query.
--
--MODIFICATION HISTORY
--19-Aug-1998 by Jonathan Gennick
--  1 Creation
--

SET VERIFY OFF
SET HEADING OFF
SET FEEDBACK OFF
SET PAGESIZE 0

--
--Display a list of statement ids for the user to choose from.
--
PROMPT
PROMPT The plan table contains execution plans
PROMPT for the following statements:
PROMPT

SELECT DISTINCT '     ', statement_id
  FROM plan_table
ORDER BY statement_id;

--
--Ask the user to enter the name of the statement for 
--which the execution plan is to be shown.
-- 
PROMPT
ACCEPT s_statement_id CHAR PROMPT 'Enter Statement ID: '
PROMPT

--
--Show the execution plan for the statement the user selected.
--
COLUMN id FORMAT 999
COLUMN step_description FORMAT A80
SELECT id, LPAD(' ', 2*(level-1)) || operation || ' ' || options 
       || ' ' || object_name || ' ' ||
       DECODE(id, 0, 'Cost = ' || position) step_description
  FROM plan_table
START WITH id = 0 AND statement_id = '&&s_statement_id'
CONNECT BY prior id = parent_id AND statement_id = '&&s_statement_id'
ORDER BY id, position;

SELECT 'PLAN_TABLE contains no execution plan for &&s_statement_id..'
  FROM dual
 WHERE '&&s_statement_id' NOT IN (
        SELECT DISTINCT statement_id
          FROM plan_table
        );  

--Restore settings to their defaults
SET HEADING ON
SET FEEDBACK ON
SET PAGESIZE 14


